==> xfxbase-2.6.37.tar.gz: lib/XAppBase.dart <==
part of xfxbase;

class XAppBase<K, U> {
  String app_Name;
  String app_Version;
  String app_BuildNumber;

  ///Chakra Petch
  String app_FontFamily;
  Color? app_MainColor;

  ///NON USARLA , usare KforScale
  double _app_KforScale = 1;
  double get KforScale => _app_KforScale;
  set KforScale(v) => XStyles.KforScaleForFont = _app_KforScale = v;

  String api_URL;
  String? blob_ConnString_XUpdater;
  String? blob_ConnString_ToSave;
  String? blob_nameAPP;
  List<XMenuGroup> liXMenus = List<XMenuGroup>.empty(growable: true);
  late Widget Function(XMenuItem) getWidget_FormMenuItem;

  K appServices;
  U appDataService;
  Isolate? dataSendBackThread;
  SendPort? dataSendBackSendMsgPort;

  PackageInfo? packageInfo;
  bool darkTheme;
  bool authentication;

  XAppBase({
    required this.appServices,
    required this.appDataService,
    this.packageInfo,
    this.dataSendBackThread,
    this.dataSendBackSendMsgPort,
    this.app_Name = "",
    this.app_Version = "",
    this.app_BuildNumber = "",
    this.app_FontFamily = "Chakra Petch",
    this.app_MainColor,
    this.api_URL = "",
    this.blob_ConnString_XUpdater = "",
    this.blob_ConnString_ToSave = "",
    this.blob_nameAPP = "",
    this.darkTheme = true,
    this.authentication = true,
  }) {
    if (Platform.isAndroid) {
      if (app_Version == "") app_Version = packageInfo != null ? packageInfo!.version : "1.0";
      if (blob_nameAPP == "" && packageInfo != null) blob_nameAPP = packageInfo!.appName.toLowerCase();

      XStyles.googleFontFamily = app_FontFamily;

      if (blob_ConnString_ToSave != null && blob_ConnString_ToSave != "") {
        azureStorage = XAzureStorage.parse(blob_ConnString_ToSave ?? "");
      }

      XColors.done = Color.fromARGB(255, 36, 136, 39);
      XUtils.widthMin_Layout = 800;
      XfxMenu.menuItem_WidthDefault = 300;
      //GET PREF se c'è lo setto in  xApp.app_KforScale
      loadPreference();
    }
  }

  Future saveFontSizePreference(String fontsize) async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    await prefs.setString("fontSize", fontsize);
  }

  loadPreference() async {
    var prefs = await SharedPreferences.getInstance();
    var res = prefs.getString("fontSize");
    if (res == null) {
      prefs.setString("fontSize", KforScale.toString());
    } else {
      KforScale = double.parse(res);
    }
  }

  loadPath() async {
    var p = Directory('/storage/emulated/0/Download/${app_Name.replaceAll(" ", "")}'); //await getExternalStorageDirectories(type: StorageDirectory.downloads);
    if (p.existsSync()) {
      XLibStorage.filePath = p.path;
    } else {
      final Directory _appDirNewFolder = await p.create(recursive: true);
      XLibStorage.filePath = _appDirNewFolder.path;
    }
  }

  static MaterialApp initMaterialApp(XAppBase xApp, Map<String, Widget Function(BuildContext)> routes, {Iterable<Locale>? supportedLocales, ThemeData? theme}) {
    const PgName_XUpdater = '';
    const PgName_XMainPage = '/';
    return MaterialApp(
      localizationsDelegates: GlobalMaterialLocalizations.delegates,
      supportedLocales: supportedLocales ?? [const Locale('it', 'IT')],
      routes: routes,
      title: xApp.app_Name,
      initialRoute: (xApp.blob_ConnString_XUpdater != "" && xApp.blob_ConnString_XUpdater != null) ? PgName_XUpdater : PgName_XMainPage,
      debugShowCheckedModeBanner: false,
      theme: theme ??
          ThemeData(
              useMaterial3: false,
              dialogTheme: DialogTheme(backgroundColor: Colors.grey[900]),
              visualDensity: VisualDensity.adaptivePlatformDensity,
              bottomSheetTheme: BottomSheetThemeData(backgroundColor: Colors.transparent),
              textTheme: TextTheme(bodyMedium: TextStyle(fontSize: 14.0, color: Colors.white)), // Testo del contenuto dello scaffold
              scaffoldBackgroundColor: Colors.black,
              colorScheme: ColorScheme(
                brightness: Brightness.dark,
                primary: Colors.white,
                onPrimary: Colors.grey[900]!, //SOLO PER i testi
                primaryContainer: Colors.amber,
                secondary: xApp.app_MainColor!, //colore che overrida lo sfondo per AppBar e Widget Base
                onSecondary: Colors.white,
                error: Colors.red,
                onError: Colors.red,
                background: Colors.transparent,
                onBackground: Colors.grey[900]!,
                surfaceTint: Color.fromARGB(255, 163, 163, 163),
                surface: xApp.app_MainColor!, //color di sfondo per AppBar e Widget Base
                onSurface: Colors.white,
              ).copyWith(
                secondary: Colors.cyan[600],
              )),
    );
  }
}

==> xfxbase-2.6.48.tar.gz: lib/XAppBase.dart <==
part of xfxbase;

class XAppBase<K, U> {
  String app_Name;
  String app_Version;
  String app_BuildNumber;

  ///Chakra Petch
  String app_FontFamily;
  Color? app_MainColor;

  ///NON USARLA , usare KforScale
  double _app_KforScale = 1;
  double get KforScale => _app_KforScale;
  set KforScale(v) => XStyles.KforScaleForFont = _app_KforScale = v;

  String api_URL;
  String? blob_ConnString_XUpdater;
  String? blob_ConnString_ToSave;
  String? blob_nameAPP;
  List<XMenuGroup> liXMenus = List<XMenuGroup>.empty(growable: true);
  late Widget Function(XMenuItem) getWidget_FormMenuItem;

  K appServices;
  U appDataService;
  Isolate? dataSendBackThread;
  SendPort? dataSendBackSendMsgPort;

  PackageInfo? packageInfo;
  bool darkTheme;
  bool authentication;

  XAppBase({
    required this.appServices,
    required this.appDataService,
    this.packageInfo,
    this.dataSendBackThread,
    this.dataSendBackSendMsgPort,
    this.app_Name = "",
    this.app_Version = "",
    this.app_BuildNumber = "",
    this.app_FontFamily = "Chakra Petch",
    this.app_MainColor,
    this.api_URL = "",
    this.blob_ConnString_XUpdater = "",
    this.blob_ConnString_ToSave = "",
    this.blob_nameAPP = "",
    this.darkTheme = true,
    this.authentication = true,
  }) {
    if (Platform.isAndroid) {
      if (app_Version == "") app_Version = packageInfo != null ? packageInfo!.version : "1.0";
      if (blob_nameAPP == "" && packageInfo != null) blob_nameAPP = packageInfo!.appName.toLowerCase();

      XStyles.googleFontFamily = app_FontFamily;

      if (blob_ConnString_ToSave != null && blob_ConnString_ToSave != "") {
        azureStorage = XAzureStorage.parse(blob_ConnString_ToSave ?? "");
      }

      XColors.done = Color.fromARGB(255, 36, 136, 39);
      XUtils.widthMin_Layout = 800;
      XfxMenu.menuItem_WidthDefault = 300;
      //GET PREF se c'è lo setto in  xApp.app_KforScale
      loadPreference();
    }
  }

  Future saveFontSizePreference(String fontsize) async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    await prefs.setString("fontSize", fontsize);
  }

  loadPreference() async {
    var prefs = await SharedPreferences.getInstance();
    var res = prefs.getString("fontSize");
    if (res == null) {
      prefs.setString("fontSize", KforScale.toString());
    } else {
      KforScale = double.parse(res);
    }
  }

  loadPath() async {
    var p = await getApplicationDocumentsDirectory(); //Directory('/storage/emulated/0/Download/${app_Name.replaceAll(" ", "")}'); //await getExternalStorageDirectories(type: StorageDirectory.downloads);
    if (p.existsSync()) {
      XLibStorage.filePath = p.path;
    } else {
      final Directory _appDirNewFolder = await p.create(recursive: true);
      XLibStorage.filePath = _appDirNewFolder.path;
    }
  }

  static MaterialApp initMaterialApp(XAppBase xApp, Map<String, Widget Function(BuildContext)> routes, {Iterable<Locale>? supportedLocales, ThemeData? theme}) {
    const PgName_XUpdater = '';
    const PgName_XMainPage = '/';
    return MaterialApp(
      localizationsDelegates: GlobalMaterialLocalizations.delegates,
      supportedLocales: supportedLocales ?? [const Locale('it', 'IT')],
      routes: routes,
      title: xApp.app_Name,
      initialRoute: (xApp.blob_ConnString_XUpdater != "" && xApp.blob_ConnString_XUpdater != null) ? PgName_XUpdater : PgName_XMainPage,
      debugShowCheckedModeBanner: false,
      theme: theme ??
          ThemeData(
              useMaterial3: false,
              dialogTheme: DialogTheme(backgroundColor: Colors.grey[900]),
              visualDensity: VisualDensity.adaptivePlatformDensity,
              bottomSheetTheme: BottomSheetThemeData(backgroundColor: Colors.transparent),
              textTheme: TextTheme(bodyMedium: TextStyle(fontSize: 14.0, color: Colors.white)), // Testo del contenuto dello scaffold
              scaffoldBackgroundColor: Colors.black,
              colorScheme: ColorScheme(
                brightness: Brightness.dark,
                primary: Colors.white,
                onPrimary: Colors.grey[900]!, //SOLO PER i testi
                primaryContainer: Colors.amber,
                secondary: xApp.app_MainColor!, //colore che overrida lo sfondo per AppBar e Widget Base
                onSecondary: Colors.white,
                error: Colors.red,
                onError: Colors.red,
                background: Colors.transparent,
                onBackground: Colors.grey[900]!,
                surfaceTint: Color.fromARGB(255, 163, 163, 163),
                surface: xApp.app_MainColor!, //color di sfondo per AppBar e Widget Base
                onSurface: Colors.white,
              ).copyWith(
                secondary: Colors.cyan[600],
              )),
    );
  }
}
